@@ -5,7 +5,7 @@ from flask_jwt_extended import JWTManager
 from flask_restful import Api
 
 from odbms import DBMS
-from .common import  Login, Account, ProjectById, ProjectRS, Document
+from .common import  Login, Account, ProjectById, ProjectRS, ProjectCloneRS, Document
 
 from .models import Admin
 from .models import Role
@@ -20,7 +20,7 @@ api = Api(app, prefix='/api')
 
 load_dotenv()
 app.secret_key =  "dsafidsalkjdsaofwpdsncdsfdsafdsafjhdkjsfndsfkjsldfdsfjaskljdf"
-#app.config['SERVER_NAME'] = os.getenv('RUNIT_SERVERNAME')
+app.config['SERVER_NAME'] = os.getenv('RUNIT_SERVERNAME')
 app.config["JWT_SECRET_KEY"] = "972a444fb071aa8ee83bf128808d255ec72e3a6b464a836b7d06254529c6"
 app.config["JWT_ACCESS_TOKEN_EXPIRES"] = timedelta(days=30)
 
@@ -38,19 +38,21 @@ api.add_resource(Login, '/login/')
 api.add_resource(Account, '/account/')
 api.add_resource(ProjectRS, '/projects/')
 api.add_resource(ProjectById, '/projects/<string:project_id>/')
+api.add_resource(ProjectCloneRS, '/projects/clone/<string:project>/')
 api.add_resource(Document, '/document/<string:project_id>/<string:collection>/')
 #api.add_resource(RunFunction, '/<string:project_id>/<string:function>/')
 #api.add_resource(FunctionRS, '/functions/')
 #api.add_resource(FunctionById, '/functions/<string:function_id>/')
 
 
-from .blueprints import public, account, functions, project, admin, setup
+from .blueprints import public, account, functions, project, database, admin, setup
 
 app.register_blueprint(setup)
 app.register_blueprint(public)
 app.register_blueprint(functions)
 app.register_blueprint(account)
 app.register_blueprint(project)
+app.register_blueprint(database)
 app.register_blueprint(admin, subdomain='admin')
 
 @app.route('/complete_setup/')
